<?php
/**
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * $Revision: 1.18 $
 * $Author: tora60 $
 * $Date: 2012-02-13 15:06:14 $
 */

defined('mxMainFileLoaded') or die('access denied');

/**
 * Definition der jeweiligen Platzhalter und deren Ersetzungen
 */
function theme_define_placeholders()
{
    global $themesetting;
    $title = theme_colorize_all($themesetting['title'], true);
    $part[] = array("{PAGE_TITLE}", $title);
    $part[] = array("{PAGE_SLOGAN}", $themesetting['slogan']);
    $part[] = array("{NAVBAR}", theme_get_navbars());
    $part[] = array("{FOOTMESSAGE}", theme_show_footmsg());
    $part[] = array("{DEBUGSERVICE}", theme_get_servicetext('debugservice'));
    $part[] = array("{SITESERVICE}", theme_get_servicetext('siteservice'));
    $part[] = array("{LAYOUT_CLASS}", theme_get_layout_class());
    $part[] = array("{CURRENTYEAR}", date('Y'));
    return $part;
}

/**
 * Definition der einzelnen Blockbereiche
 */
function theme_define_blocks()
{
    global $themesetting;
    static $var;
    if (isset($var)) return $var;
    // linke Bloecke
    $name = 'block_left';
    $var[$name]['container'] = 'blocks_left_loop';
    $var[$name]['function'] = 'themesidebox';
    $var[$name]['position'] = 'l';
    /* einfache Moeglichkeit, die linken Bloecke bei bestimmten Seiten zu entfernen */
    if (theme_hideleftblocks() && MX_MODULE != 'admin') {
        unset($var[$name]);
    }
    // obere Center-Bloecke
    $name = 'block_center_top';
    $var[$name]['container'] = 'blocks_center_top_loop';
    $var[$name]['function'] = 'thememiddlebox';
    $var[$name]['position'] = 'c';
    // untere Center-Bloecke
    $name = 'block_center_down';
    $var[$name]['container'] = 'blocks_center_down_loop';
    $var[$name]['function'] = 'thememiddlebox';
    $var[$name]['position'] = 'd';
    // rechte Bloecke
    $name = 'block_right';
    $var[$name]['container'] = 'blocks_right_loop';
    $var[$name]['function'] = 'themesidebox';
    $var[$name]['position'] = 'r';
    return $var;
}

/**
 * Definition des Contentbereiches inkl. der open/close-Table Funktionen
 */
function theme_define_content()
{
    static $var;
    if (isset($var)) return $var;
    // die Funktion OpenTable()
    $var['opentabs']['OpenTable']['templatevar'] = 'opentable';
    $var['opentabs']['OpenTable']['innerreplace'] = '{OPENCLOSE_TABLE}'; // hier kann irgendwas stehen, es muss aber mit dem entsprechenden Text innerhalb der template-Datei uebereinstimmen...
    // die Funktion OpenTable2()
    $var['opentabs']['OpenTable2']['templatevar'] = 'opentable2';
    $var['opentabs']['OpenTable2']['innerreplace'] = '{OPENCLOSE_TABLE_2}';
    // die Funktion OpenTableAl()
    $var['opentabs']['OpenTableAl']['templatevar'] = 'opentableal';
    $var['opentabs']['OpenTableAl']['innerreplace'] = '{OPENCLOSE_TABLE_AL}';
    // die Funktion themeindex() / News Modul
    $var['themeindex'] = 'themeindex';
    // die Funktion themearticle() / News Modul
    $var['themearticle'] = 'themearticle';
    // der Name (output_container) darf nicht veraendert werden !!
    $var['output_container'] = 'script_output';
    // der Name (index_on_container) darf nicht veraendert werden !!
    $var['index_on_container'] = 'blocks_right_container';
    $var['index_on_block_container'] = 'blocks_right_loop';
    // der Name (more_header) darf nicht veraendert werden !!
    $var['add_header'] = 'more_header';

    return $var;
}

/**
 * ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
 * diese Teile werden gleich zu Beginn des scriptes, beim einlesen des templates, ersetzt
 * Vorsicht, wenn das Theme gecached werden soll!!!
 * Dann duerfen hier keine dynamischen Elemente eingesetzt werden.
 */
function theme_replace_start($template)
{
    /**
     * bestimmte Texte, vor allem Image-Pfade, die ersetzt werden sollen, definieren (suche/ersetze)
     */
    $part[] = array('"style/', '"' . MX_THEME_DIR . '/style/'); // die Stylesheets
    // $part[] = array('"images/', '"' . MX_THEME_DIR . '/images/'); // normale images im theme
    // $part[] = array('url(images/', 'url(' . MX_THEME_DIR . '/images/');
    // $part[] = array('"js/', '"' . MX_THEME_DIR . '/js/');
    // Suchformular entfernen, wenn Suche abgeschaltet ist
    if (!mxModuleAllowed('Search')) {
        theme_extract_optional_part($template, 'searchform', '<br />');
    }
    // Siteservicebereich entfernen, wenn Siteservice abgeschaltet oder leer ist
    if (!theme_get_servicetext('siteservice')) {
        theme_extract_optional_part($template, 'siteservice', '');
    }
    // Debugbereich entfernen, wenn Debugmodus abgeschaltet oder leer ist
    if (!theme_get_servicetext('debugservice')) {
        theme_extract_optional_part($template, 'debugservice', '');
    }
    // das Kopfmenue durch die tatsaechlichen Daten ersetzen
    theme_extract_optional_part($template, 'headmenue', '{NAVBAR}');

    return theme_replace_parts($template, $part);
}

/**
 * ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
 * diese Teile werden vor der Ausgabe des headers im Headbereich ersetzt
 */
function theme_replace_header($newheader)
{
    /* Der Farbwaehler */
    $part[] = array("{THEMEBASECOLOR}", theme_get_layout_color());
    // alles ersetzen und Rckgabe...
    return theme_replace_parts($newheader, $part);
}

/**
 * ersetzen in jedem einzelnen Block
 */
function theme_replace_blocks($template, $block)
{
    global $themesetting;
    switch ($block['position']) {
        case 'l':
        case 'r':
        case 'c':
        case 'd':
            break;
    }

    /* Teil fuer alle Bloecke */
    if (empty($block['title']) || $block['title'] == 'NOTITLE') {
        $part[] = array('__BLOCK_ID__' , '__BLOCK_ID__ block-hide-caption');
        $part['preg'][] = array('#<h[1-6]>\s*(NOTITLE)*\s*</h[1-6]>#' , '');
    }
    $part[] = array('__BLOCK_ID__' , 'block-' . $block['position'] . '-' . $block['order']);

    if (isset($part)) {
        return theme_replace_parts($template, $part);
    }
    return $template;
}

/**
 * ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
 * diese Teile werden am Ende des scriptes, in der Funktion themefooter() ersetzt
 */
function theme_replace_end($template)
{
    global $themesetting;

    /* einfache Moeglichkeit, die linken Bloecke bei bestimmten Seiten zu entfernen */
    if (theme_hideleftblocks()) {
        theme_extract_part($template, 'blocks_left_container');
    }

    if (isset($part)) {
        return theme_replace_parts($template, $part);
    }
    return $template;
}

/**
 * Die verschiedenen Layout-Spalten definieren
 */
function theme_get_layout_class()
{
    global $themesetting;

    /* Die verschiedenen Layout-Spalten definieren */
    if (theme_hideleftblocks()) {
        /* einfache Moeglichkeit, die linken Bloecke bei bestimmten Seiten zu entfernen */
        // einspaltiges Layout
        return 'hideboth';
    } else if (!$GLOBALS['index']) {
        // zweispaltiges Layout
        return 'hidecol2';
    } else {
        // dreispaltiges Layout > Standard
        return 'hidenone';
    }
}

/**
 * Die Navigationsbuttons in der Artikelliste des Newsmoduls
 */
function getThemeIndexButtons($story)
{
    global $theme_template;
    static $img, $isnewsadmin;
    if (!isset($isnewsadmin)) {
        $isnewsadmin = mxGetAdminPref('radminarticle');
    }
    if (empty($img)) {
        // die images werden in einen statischen Variable gehalten um die Bildgroessen nicht bei jedem Artikel zu ermitteln
        // xx als alttext wird weiter unten dynamisch ersetzt
        $img[1] = mxCreateImage(MX_THEME_DIR . '/images/buttons/informant.gif', 'xx', array('title' => 'xx'));
        $img[2] = mxCreateImage(MX_THEME_DIR . '/images/buttons/print.gif', _BMXPRINTER, array('title' => _BMXPRINTER));
        $img[3] = mxCreateImage(MX_THEME_DIR . '/images/buttons/friend.gif', _BMXFRIEND, array('title' => _BMXFRIEND));
        $img[4] = mxCreateImage(MX_THEME_DIR . '/images/buttons/counter.gif', 'xx', array('title' => 'xx'));
        $img[6] = mxCreateImage(MX_THEME_DIR . '/images/buttons/bytesmore.gif', 'xx', array('title' => 'xx'));
        if ($GLOBALS['articlecomm']) $img[5] = mxCreateImage(MX_THEME_DIR . '/images/buttons/comments.gif', 'xx', array('title' => 'xx'));
        // mxdebugfuncvars($story['allmorelink']); // zum ansehen der morelink-Parameter einkommentieren
        // mxdebugfuncvars($story);                // zum ansehen der story-Parameter der ersten story einkommentieren
    }
    // mxdebugfuncvars($story);                  // zum ansehen der story-Parameter aller stories einkommentieren
    $bmore = ($story['allmorelink']['bodycount']) ? _READMORE . " (" . $story['allmorelink']['bodycount'] . ' ' . _BYTESMORE . ")" : _READMORE;
    $adminlink = ($isnewsadmin) ? " href='admin.php?op=EditStory&amp;sid=" . $story['sid'] . "' " : "";
    $link[] = $story['allmorelink']['storylink'] . str_replace("xx", $bmore, $img[6]) . "</a>";
    if ($story['informant'] != $GLOBALS['anonymous'] && (MX_IS_USER || MX_IS_ADMIN)) {
        $link[] = $story['allmorelink']['informantlink'] . str_replace("xx", _USERINFO . ": " . $story['informant'], $img[1]) . "</a>";
    }
    $link[] = $story['allmorelink']['printerlink'] . $img[2] . "</a>";
    if (mxModuleAllowed('Recommend_Us')) {
        $link[] = $story['allmorelink']['friendlink'] . $img[3] . "</a>";
    }
    if (empty($story['acomm']) && $GLOBALS['articlecomm']) { // Achtung!!! acomm: 0 = Ja , 1 = Nein
        $link[] = $story['allmorelink']['commentslink'] . str_replace("xx", _COMMENTS . " (" . $story['comments'] . ")", $img[5]) . "</a>";
    }
    $link[] = "<a title='" . $story['allmorelink']['counter'] . ", " . $story['allmorelink']['score'] . "' " . $adminlink . ">" . str_replace("xx", $story['counter'] . ' ' . _READS, $img[4]) . "</a>";
    return $link;
}

function theme_get_layout_color()
{
    global $themesetting;
    foreach ($themesetting['headnav'] as $title => $menue) {
        if (in_array(1, $menue['case'])) {
            if ($menue['color']) {
                return $menue['color'];
            } else {
                return $themesetting['basecolor'];
            }
        }
    }
    /* wenn nix gefunden, dann Standard zurueck.. */
    return $themesetting['basecolor'];
}

/**
 * pruefen ob linke Bloecke ausgeblendet werden sollen
 */
function theme_hideleftblocks()
{
    global $themesetting;
    return (isset($themesetting['noblock']) && in_array(1, $themesetting['noblock']));
}

/* die Navigationsbuttons im header, Quelle in settings.php */
function theme_get_navbars()
{
    global $themesetting;
    foreach ($themesetting['headnav'] as $title => $menue) {
        if (empty($current) && in_array(1, $menue['case'])) {
            $current = ' id="nav-current"';
        } else {
            $current = '';
        }
        $part[] = '<li' . $current . '><a href="' . $menue['link'] . '">' . $title . '</a></li>';
    }
    // mxDebugFuncVars($themesetting, $part);
    return implode("\n", $part);
}

/* die Navigationsbuttons im header, Quelle in settings.php */
function theme_get_navbars2()
{
    global $themesetting;
    foreach ($themesetting['headnav2'] as $title => $menue) {
        if (empty($current) && in_array(1, $menue['case'])) {
            $current = ' id="current"';
        } else {
            $current = '';
        }
        $part[] = '<a href="' . $menue['link'] . '"' . $current . '>' . $title . '</a>';
    }
    // mxDebugFuncVars($themesetting, $part);
    return implode(" | ", $part);
}

/* einen beliebigen Text bunt einfaerben */
function theme_colorize_all($title, $trim = false)
{
    $check = explode(' ', str_replace('  ', ' ', $title));
    $max_i = count($check);
    $y = 0;
    $class = array('',
        ' class="base-color"',
        // ' class="color-gray"',
        );
    $max_y = count($class);

    for ($i = 0; $i < $max_i; $i++) {
        $check[$i] = '<span' . $class[$y] . '>' . $check[$i] . '</span>';
        $y++;
        if ($y == $max_y) {
            $y = 0;
        }
    }
    if ($trim) {
        return implode('', $check);
    } else {
        return implode(' ', $check);
    }
}

/**
 * in $newheader ist der gesamte angepasste header enthalten
 */
function theme_header($newheader, &$siteservice, &$debugservice)
{
    global $theme_template, $themesetting;
    /* das Theme verwendet eigene Servicebereiche, deswegen hier die beiden Variablen killen */
    $siteservice = null;
    $debugservice = null;
    /* den body-Tag hinter head-Ende setzen >> nicht veraendern !! */
    $newheader .= "\n</head>\n\n" . $theme_template['body_tag'] . "\n\n";
    /* bei Bedarf den XHTML-Dokumenttyp ueberpruefen und Fehlermeldung ausgeben */
    if (MX_IS_ADMIN && !theme_check_xhtmldoctype()) {
        $newheader .= '<div class="warning"><h2 class="align-center">' . _THEME_FALSEDOCTYPE . '</h2></div>';
    }
    // ersetzen von eigenen Theme-Elementen, kann veraendert und ergaenzt werden
    // diese Teile werden vor der Ausgabe des headers im Headbereich ersetzt
    $newheader = theme_replace_header($newheader);

    return $newheader;
}

/**
 * parsen der Seiten-Bloecke
 */
function themesidebox($title, $content, $block = array(), $noecho = 0)
{
    global $theme_template;
    if (empty($block)) {
        $block['position'] = "l";
    }
    $out = ($block['position'] == "r") ? $theme_template['block_right'] : $theme_template['block_left'];
    $out = str_replace('{BLOCK_CONTENT}' , $content , $out);
    $out = str_replace('{BLOCK_TITLE}' , $title , $out);
    if ($noecho) {
        return $out;
    } else {
        echo $out;
    }
}

/**
 * parsen der Center-Bloecke
 */
function thememiddlebox($title, $content, $block = array(), $noecho = 0)
{
    global $theme_template;
    if (empty($block)) {
        $block['position'] = "c";
    }
    $out = ($block['position'] == "d") ? $theme_template['block_center_down'] : $theme_template['block_center_top'];
    $out = str_replace('{BLOCK_CONTENT}' , $content , $out);
    $out = str_replace('{BLOCK_TITLE}' , $title , $out);
    if ($noecho) {
        return $out;
    } else {
        echo $out;
    }
}

/**
 * News Modul Artikelliste (index.php)
 * $x bedeutet: nicht verwendet, nur zur nuke-Modulkompatibilitaet
 */
function themeindex($x, $x, $x, $x, $x, $x, $x, $x, $x, $x, $x, $x, $story = array())
{
    global $theme_template;
    pmxHeader::add_style(MX_THEME_DIR . '/style/news.css');
    // nur eine Spalte zulassen :-)
    $GLOBALS['storyhome_cols'] = 1;
    $cattitle = (empty($story['cattitle'])) ? '' : ' <span class="story-cat-title">(' . $story['allmorelink']['categorie'] . ')</span>';
    $authorinfo = (empty($story['informant']) || $story['informant'] == $GLOBALS['anonymous']) ? theme_adminname($story) : " " . $story['allmorelink']['informantlink'] . $story['informant'] . "</a>";
    $story['topicimage'] = mxCreateImage($GLOBALS['tipath'] . $story['topicimage'], $story['topictext'], 0, 'align="left" class="post-topicimage"');
    $story['title'] = strip_tags($story['title']) . $cattitle;
    $story['content'] = $story['hometext'];
    if (!$story['acomm'] && $GLOBALS['articlecomm']) { // Achtung!!! acomm: 0 = Ja , 1 = Nein
        $story['comments'] = '<a href="modules.php?name=News&amp;file=article&amp;sid=' . $story['sid'] . '#comments" class="comments">' . _COMMENTS . ' (' . $story['comments'] . ')</a>';
    } else {
        $story['comments'] = '';
    }
    if (empty($story['allmorelink']['bodycount'])) {
        $story['readmore'] = '';
    } else {
        $title = ($story['allmorelink']['bodycount']) ? ' title="' . $story['allmorelink']['bodycount'] . ' ' . _BYTESMORE . '"' : '';
        $story['readmore'] = '<a href="modules.php?name=News&amp;file=article&amp;sid=' . $story['sid'] . '" class="readmore"' . $title . '>' . _HREADMORE . '</a>';
    }
    $story['datetime'] = '<span class="date">' . $story['datetime'] . '</span>';
    // die oben definierten Variablen in dem passenden templateteil ersetzen
    $artvars = theme_define_content();
    echo theme_replace_vars($theme_template[$artvars['themeindex']], $story);
    return;
}

/**
 * News Modul Artikelansicht (article.php)
 * $x bedeutet: nicht verwendet, nur zur nuke-Modulkompatibilitaet
 */
function themearticle($x, $x, $x, $x, $x, $x, $x, $x, $x, $story = array())
{
    global $theme_template;
    pmxHeader::add_style(MX_THEME_DIR . '/style/news.css');
    $authorinfo = (empty($story['informant']) || $story['informant'] == $GLOBALS['anonymous']) ? theme_adminname($story) : " " . $story['allmorelink']['informantlink'] . $story['informant'] . "</a>";
    $story['infoline'] = _NEWSSUBMITED . " " . $authorinfo . " " . $story['allmorelink']['datetime'];
    $story['topicimage'] = mxCreateImage($GLOBALS['tipath'] . $story['topicimage'], $story['topictext'], 0, 'align="left" class="post-topicimage"');
    $story['title'] = strip_tags($story['title']);
    $story['content'] = $story['hometext'] . "<br />\n" . $story['bodytext'];
    $story['notes'] = (empty($story['notes'])) ? '' : '<p class="story-notes">' . _NOTE . '</p><p>' . $story['notes'] . '</p>';
    // die oben definierten Variablen in dem passenden templateteil ersetzen
    echo theme_replace_vars($theme_template['themearticle'], $story);
    return;
}

?>